@@ -1,11 +1,11 @@
 from django.core.management.base import BaseCommand
 from optparse import make_option
-from django_test import CustomTestRunner, command_line_options
+from django_test import CustomTestRunner, COMMAND_LINE_OPTIONS
 
 
 class Command(BaseCommand):
   option_list = list(BaseCommand.option_list) + \
-                [make_option(*o.args, **o.kwargs) for o in command_line_options]
+                [make_option(*o.args, **o.kwargs) for o in COMMAND_LINE_OPTIONS]
 
 
   def handle(self, *args, **options):
